| Title: | 'Imath' Computer Graphics Linear Algebra Static Library |
|---|---|
| Description: | Provides a static library for 'Imath' (see <https://github.com/AcademySoftwareFoundation/Imath>), a library for functions and data types common in computer graphics applications, including a 16-bit floating-point type. |
| Authors: | Tyler Morgan-Wall [aut, cre] (ORCID: <https://orcid.org/0000-0002-3131-3814>), Andrew Kunz [ctb, cph], Antonio Rojas [ctb, cph], Brecht Van Lommel [ctb, cph], Cary Phillips [ctb, cph], Christina Tempelaar-Lietz [ctb, cph], Christopher Kulla [ctb, cph], Daniel Kaneider [ctb, cph], Dirk Lemstra [ctb, cph], Ed Hanway [ctb, cph], Eric Wimmer [ctb, cph], Florian Kainz [ctb, cph], Gregorio Litenstein [ctb, cph], Harry Mallon [ctb, cph], Huibean Luo [ctb, cph], Jean-Marie Aubry [ctb, cph], Jens Lindgren [ctb, cph], Ji Hun Yu [ctb, cph], Jonathan Stone [ctb, cph], Jules Maselbas [ctb, cph], Kazuki Sakamoto [ctb, cph], Kimball Thurston [ctb, cph], Larry Gritz [ctb, cph], Liam Fernandez [ctb, cph], Lucas Miller [ctb, cph], Mark Sisson [ctb, cph], Mathieu Malaterre [ctb, cph], Mathieu Westphal [ctb, cph], Matthäus G. Chajdas [ctb, cph], Matthias C. M. Troffaes [ctb, cph], Nicholas Yue [ctb, cph], Nick Porcino [ctb, cph], Nick Rasmussen [ctb, cph], Nicolas Chauvet [ctb, cph], Nigel Stewart [ctb, cph], Owen Thompson [ctb, cph], Peter Hillman [ctb, cph], Piotr Barejko [ctb, cph], Piotr Stanczyk [ctb, cph], Ralph Potter [ctb, cph], Richard Hobbes [ctb, cph], Simon Boorer [ctb, cph], Thanh Ha [ctb, cph], Thorsten Kaufmann [ctb, cph], Xiao Zhai [ctb, cph], Yujie Shu [ctb, cph], Yuya Asano [ctb, cph], Zachary Klein [ctb, cph], Kevin Ushey [cph] |
| Maintainer: | Tyler Morgan-Wall <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 3.2.2-1 |
| Built: | 2026-05-30 02:35:35 UTC |
| Source: | https://github.com/tylermorganwall/libimath |
This rotates a point around the origin at the angles specified. This function is primarily just included as an example of integrating the Imath library into a package. See imath-info.cpp in the source for the corresponding C++ code.
imath_rotate_point(point, angles)imath_rotate_point(point, angles)
point |
A length-3 numeric vector (x, y, z) |
angles |
A length-3 numeric vector (rotation angles in radians) |
The rotated point as an R numeric vector
# This rotates a point around an angle. point = c(1.0, 0.0, 0.0) angles = c(0.0, pi/4, 0.0) imath_rotate_point(point, angles)# This rotates a point around an angle. point = c(1.0, 0.0, 0.0) angles = c(0.0, pi/4, 0.0) imath_rotate_point(point, angles)
Print the Imath library version info
print_imath_version()print_imath_version()
None.
# Print the Imath version provided in the static library print_imath_version()# Print the Imath version provided in the static library print_imath_version()